package com.jiuqi.dna.ide.designer.parts;

import com.jiuqi.dna.ide.designer.elements.DesignerElement;
import com.jiuqi.dna.ide.designer.elements.ICompositeElement;
import com.jiuqi.dna.ide.designer.elements.IDesignerElement;
import com.jiuqi.dna.ide.designer.elements.IFigureElement;
import com.jiuqi.dna.ide.designer.elements.ILayoutElement;
import com.jiuqi.dna.ide.designer.events.CompositeAdapter;
import com.jiuqi.dna.ide.designer.events.CompositeEvent;
import com.jiuqi.dna.ide.designer.events.ICompositeListener;
import com.jiuqi.dna.ide.designer.policies.CompositeEditPolicy;
import com.jiuqi.dna.ide.designer.policies.DesignerXYLayoutEditPolicy;
import com.jiuqi.dna.ide.designer.policies.ILayoutEditPolicyProvider;
import com.jiuqi.dna.ide.designer.toolkit.LayoutDescriptor;
import java.util.ArrayList;
import org.eclipse.gef.LayerConstants;

/* loaded from: com_jiuqi_dna_ide_designer_parts.jar:com/jiuqi/dna/ide/designer/parts/CompositeEditPart.class */
public class CompositeEditPart extends FigureEditPart implements LayerConstants {
    private ILayoutEditPolicyProvider layoutEditPolicyProvider;
    private ICompositeListener compositeListener = new CompositeAdapter() { // from class: com.jiuqi.dna.ide.designer.parts.CompositeEditPart.1
        public void childAdd(CompositeEvent event) {
            if (event.composite == CompositeEditPart.this.getModel() && (event.child instanceof IFigureElement)) {
                CompositeEditPart.this.refreshChildren();
            }
        }

        public void childRemove(CompositeEvent event) {
            if (event.composite == CompositeEditPart.this.getModel() && (event.child instanceof IFigureElement)) {
                CompositeEditPart.this.refreshChildren();
            }
        }

        public void layoutChange(CompositeEvent event) {
            if (event.composite == CompositeEditPart.this.getModel()) {
                CompositeEditPart.this.refresh();
            }
        }

        public void layoutChangeProperty(CompositeEvent event) {
            if (event.composite == CompositeEditPart.this.getModel()) {
                CompositeEditPart.this.refresh();
            }
        }
    };

    @Override // com.jiuqi.dna.ide.designer.parts.FigureEditPart
    public void activate() {
        super.activate();
        DesignerElement designerElement = (IDesignerElement) getModel();
        if (designerElement instanceof DesignerElement) {
            DesignerElement elem = designerElement;
            elem.getDesigner().addCompositeListener(this.compositeListener);
        }
    }

    @Override // com.jiuqi.dna.ide.designer.parts.FigureEditPart
    public void deactivate() {
        super.deactivate();
        DesignerElement designerElement = (IDesignerElement) getModel();
        if (designerElement instanceof DesignerElement) {
            DesignerElement elem = designerElement;
            elem.getDesigner().removeCompositeListener(this.compositeListener);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.jiuqi.dna.ide.designer.parts.FigureEditPart
    public void createEditPolicies() {
        super.createEditPolicies();
        installEditPolicy("ContainerEditPolicy", new CompositeEditPolicy());
        installLayoutPolicies();
    }

    protected void installLayoutPolicies() {
        ICompositeElement composite = getCastedModel();
        ILayoutElement layout = composite.getLayout();
        DesignerXYLayoutEditPolicy designerXYLayoutEditPolicy = null;
        if (layout == null) {
            designerXYLayoutEditPolicy = new DesignerXYLayoutEditPolicy();
        } else if (layout.getLayoutDescriptor() != null) {
            LayoutDescriptor layoutDescriptor = layout.getLayoutDescriptor();
            if (this.layoutEditPolicyProvider != null) {
                designerXYLayoutEditPolicy = this.layoutEditPolicyProvider.createLayoutEditPolicy(layoutDescriptor);
            }
        } else {
            designerXYLayoutEditPolicy = new DesignerXYLayoutEditPolicy();
        }
        installEditPolicy("LayoutEditPolicy", designerXYLayoutEditPolicy);
    }

    private ICompositeElement getCastedModel() {
        return (ICompositeElement) getModel();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* renamed from: getModelChildren, reason: merged with bridge method [inline-methods] */
    public ArrayList<? extends IFigureElement> m0getModelChildren() {
        return getCastedModel().getFigureChildren();
    }

    public ILayoutEditPolicyProvider getLayoutEditPolicyProvider() {
        return this.layoutEditPolicyProvider;
    }

    public void setLayoutEditPolicyProvider(ILayoutEditPolicyProvider layoutEditPolicyProvider) {
        this.layoutEditPolicyProvider = layoutEditPolicyProvider;
    }
}
